// $Id: EOAdaptorDataSource.h,v 1.1.1.1 2003/07/09 22:57:43 cvs Exp $

#ifndef __EOAdaptorDataSource_h__
#define __EOAdaptorDataSource_h__

#import <EOControl/EODataSource.h>

@class NSArray, NSDictionary;
@class EOFetchSpecification, EOAdaptorChannel, EOQualifier;

/*
  Fetch dictionaries from database tables.
  The tablename has to be set in [FetchSpecification entityName].
  Qualifier, sortOrdering, distinct will be evaluated.
  It handles now tables with more than one primary key.
  Its possible to set the primary key in the fetchspecification hints
  (EOPrimaryKeyAttributeNamesHint -> array with strings as columnnames
  for the PKeys; EOPrimaryKeyAttributesHint -> array with EOAttributes for
  the PKeys).
  If no primary key is set, and now primary key could find in the table
  schema, all keys will be taken as primary keys.
  If only one primary key exsist, in insert object a new key will be generatet,
  else all keys has to be set.
  If fetch hint EOFetchResultTimeZone is set (NSTimeZone), this timezone will
  be set in date objectes.
*/

extern NSString *EOPrimaryKeyAttributeNamesHint;
extern NSString *EOPrimaryKeyAttributesHint;
extern NSString *EOFetchResultTimeZone;

@interface EOAdaptorDataSource : EODataSource
{
@private
  EOFetchSpecification *fetchSpecification;
@protected
  EOAdaptorChannel     *adChannel;
  EOQualifier          *__qualifier;
  NSArray              *__attributes;
  BOOL                 commitTransaction;
  NSDictionary         *connectionDictionary;
}

- (id)initWithAdaptorChannel:(EOAdaptorChannel *)_channel;

- (id)initWithAdaptorChannel:(EOAdaptorChannel *)_channel
  connectionDictionary:(NSDictionary *)_connDict;

- (id)initWithAdaptorName:(NSString *)_adName
  connectionDictionary:(NSDictionary *)_dict
  primaryKeyGenerationDictionary:(NSDictionary *)_pkGen;  


/*
  Returns an array with dictionaries, who contains key/values from the
  entity (use entityName/qualifier/sortOrdering). 
  Also it contains an key named 'globalID'. If EOAdaptorDataSource is
  initialized with initWithAdaptorChannel the globaID is an EOKeyGlobalID
  else if it is initialized with initWithAdaptorName the globalID is and
  EOAdaptorGlobalID.
*/
- (NSArray *)fetchObjects;

/*
  returns an mutable dictionary 
*/
- (id)createObject;

- (void)insertObject:(id)_obj;
- (void)deleteObject:(id)_obj;
- (void)updateObject:(id)_obj;
 
- (void)setFetchSpecification:(EOFetchSpecification *)_fs;
- (EOFetchSpecification *)fetchSpecification;

/* for subclasses */
- (EOAdaptorChannel *)beginTransaction;
- (void)commitTransaction;
- (void)rollbackTransaction;

- (void)openChannel;
- (void)closeChannel;
@end

#endif /* __EOAdaptorDataSource_h__ */
